Package 'glycoverse'

Title: Easy Install and Load the `Glycoverse`
Description: The 'glycoverse' is a set of packages that together form a comprehensive pipeline for glycomics and glycoproteomics data analysis. This package is designed to make it easy to install and load multiple 'glycoverse' packages in a single step.
Authors: Bin Fu [aut, cre] (ORCID: <https://orcid.org/0000-0001-8567-2997>)
Maintainer: Bin Fu <[email protected]>
License: MIT + file LICENSE
Version: 0.3.1
Built: 2026-05-26 15:24:59 UTC
Source: https://github.com/glycoverse/glycoverse

Help Index


Conflicts between the glycoverse and other packages

Description

This function lists all the conflicts between packages in the glycoverse and other packages that you have loaded.

Usage

glycoverse_conflicts(only = NULL)

Arguments

only

Set this to a character vector to restrict to conflicts only with these packages.

Details

There are four conflicts that are deliberately ignored: intersect, union, setequal, and setdiff from dplyr. These functions make the base equivalents generic, so shouldn't negatively affect any existing code.

Examples

glycoverse_conflicts()

List all glycoverse dependencies

Description

List all glycoverse dependencies

Usage

glycoverse_deps(recursive = FALSE, repos = getOption("repos"))

Arguments

recursive

If TRUE, will also list all dependencies of glycoverse packages.

repos

The repositories to use to check for updates. Defaults to getOption("repos").


List all packages in the glycoverse

Description

List all packages in the glycoverse

Usage

glycoverse_packages(include_self = TRUE)

Arguments

include_self

Include glycoverse in the list?

Examples

glycoverse_packages()

Get a situation report on the glycoverse

Description

This function gives a quick overview of the versions of R and RStudio as well as all glycoverse packages. It's primarily designed to help you get a quick idea of what's going on when you're helping someone else debug a problem.

Usage

glycoverse_sitrep()

Update glycoverse packages

Description

This checks r-universe for all glycoverse packages (and optionally, their dependencies) and reports which ones have newer versions available. You can then choose to update automatically or get manual instructions.

Usage

glycoverse_update(
  recursive = FALSE,
  repos = getOption("repos"),
  dev_to_latest = NULL
)

Arguments

recursive

If TRUE, will also list all dependencies of glycoverse packages.

repos

The repositories to use to check for updates. Defaults to getOption("repos").

dev_to_latest

If TRUE, replace development versions (versions with a 4th component >= 9000, e.g., ⁠0.1.0.9000⁠) with the latest release versions. If FALSE, keep development versions as-is. If NULL (the default), and in interactive mode, the user will be prompted. In non-interactive mode, NULL defaults to FALSE.

Examples

## Not run: 
glycoverse_update()

## End(Not run)