| Title: | Easy Install and Load the `Glycoverse` |
|---|---|
| Description: | The 'glycoverse' is a set of packages that together form a comprehensive pipeline for glycomics and glycoproteomics data analysis. This package is designed to make it easy to install and load multiple 'glycoverse' packages in a single step. |
| Authors: | Bin Fu [aut, cre] (ORCID: <https://orcid.org/0000-0001-8567-2997>) |
| Maintainer: | Bin Fu <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.3.1 |
| Built: | 2026-05-26 15:24:59 UTC |
| Source: | https://github.com/glycoverse/glycoverse |
This function lists all the conflicts between packages in the glycoverse and other packages that you have loaded.
glycoverse_conflicts(only = NULL)glycoverse_conflicts(only = NULL)
only |
Set this to a character vector to restrict to conflicts only with these packages. |
There are four conflicts that are deliberately ignored: intersect,
union, setequal, and setdiff from dplyr. These functions
make the base equivalents generic, so shouldn't negatively affect any
existing code.
glycoverse_conflicts()glycoverse_conflicts()
List all glycoverse dependencies
glycoverse_deps(recursive = FALSE, repos = getOption("repos"))glycoverse_deps(recursive = FALSE, repos = getOption("repos"))
recursive |
If |
repos |
The repositories to use to check for updates.
Defaults to |
List all packages in the glycoverse
glycoverse_packages(include_self = TRUE)glycoverse_packages(include_self = TRUE)
include_self |
Include glycoverse in the list? |
glycoverse_packages()glycoverse_packages()
This function gives a quick overview of the versions of R and RStudio as well as all glycoverse packages. It's primarily designed to help you get a quick idea of what's going on when you're helping someone else debug a problem.
glycoverse_sitrep()glycoverse_sitrep()
This checks r-universe for all glycoverse packages (and optionally, their dependencies) and reports which ones have newer versions available. You can then choose to update automatically or get manual instructions.
glycoverse_update( recursive = FALSE, repos = getOption("repos"), dev_to_latest = NULL )glycoverse_update( recursive = FALSE, repos = getOption("repos"), dev_to_latest = NULL )
recursive |
If |
repos |
The repositories to use to check for updates.
Defaults to |
dev_to_latest |
If |
## Not run: glycoverse_update() ## End(Not run)## Not run: glycoverse_update() ## End(Not run)